@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2010 The PHP Group                                |
+   | Copyright (c) 1997-2011 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: text.c 293036 2010-01-03 09:23:27Z sebastian $ */
+/* $Id: text.c 306939 2011-01-01 02:19:59Z felipe $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -160,7 +160,7 @@ PHP_FUNCTION(dom_text_split_text)
 	}
 	DOM_GET_OBJ(node, id, xmlNodePtr, intern);
 
-	if (node->type != XML_TEXT_NODE) {
+	if (node->type != XML_TEXT_NODE && node->type != XML_CDATA_SECTION_NODE) {
 		RETURN_FALSE;
 	}
 
