@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2006 The PHP Group                                |
+  | Copyright (c) 1997-2011 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -18,7 +18,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: php_pdo_int.h,v 1.17.2.6.2.1 2006/05/11 22:43:44 helly Exp $ */
+/* $Id: php_pdo_int.h 306939 2011-01-01 02:19:59Z felipe $ */
 
 /* Stuff private to the PDO extension and not for consumption by PDO drivers
  * */
@@ -32,12 +32,12 @@ void pdo_dbh_init(TSRMLS_D);
 void pdo_stmt_init(TSRMLS_D);
 
 extern zend_object_value pdo_dbh_new(zend_class_entry *ce TSRMLS_DC);
-extern zend_function_entry pdo_dbh_functions[];
+extern const zend_function_entry pdo_dbh_functions[];
 extern zend_class_entry *pdo_dbh_ce;
 extern ZEND_RSRC_DTOR_FUNC(php_pdo_pdbh_dtor);
 
 extern zend_object_value pdo_dbstmt_new(zend_class_entry *ce TSRMLS_DC);
-extern zend_function_entry pdo_dbstmt_functions[];
+extern const zend_function_entry pdo_dbstmt_functions[];
 extern zend_class_entry *pdo_dbstmt_ce;
 void pdo_dbstmt_free_storage(pdo_stmt_t *stmt TSRMLS_DC);
 zend_object_iterator *pdo_stmt_iter_get(zend_class_entry *ce, zval *object, int by_ref TSRMLS_DC);
@@ -46,7 +46,7 @@ int pdo_stmt_describe_columns(pdo_stmt_t *stmt TSRMLS_DC);
 int pdo_stmt_setup_fetch_mode(INTERNAL_FUNCTION_PARAMETERS, pdo_stmt_t *stmt, int skip_first_arg);
 
 extern zend_object_value pdo_row_new(zend_class_entry *ce TSRMLS_DC);
-extern zend_function_entry pdo_row_functions[];
+extern const zend_function_entry pdo_row_functions[];
 extern zend_class_entry *pdo_row_ce;
 void pdo_row_free_storage(pdo_stmt_t *stmt TSRMLS_DC);
 extern zend_object_handlers pdo_row_object_handlers;
