@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2010 The PHP Group                                |
+   | Copyright (c) 1997-2011 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_open_temporary_file.c 294724 2010-02-07 20:15:58Z pajoye $ */
+/* $Id: php_open_temporary_file.c 307375 2011-01-11 12:57:19Z iliaa $ */
 
 #include "php.h"
 
@@ -149,7 +149,11 @@ static int php_do_open_temporary_file(const char *path, const char *pfx, char **
 	if (GetTempFileName(new_state.cwd, pfx, 0, opened_path)) {
 		/* Some versions of windows set the temp file to be read-only,
 		 * which means that opening it will fail... */
-		VCWD_CHMOD(opened_path, 0600);
+		if (VCWD_CHMOD(opened_path, 0600)) {
+			efree(opened_path);
+			free(new_state.cwd);
+			return -1;
+		}
 		fd = VCWD_OPEN_MODE(opened_path, open_flags, 0600);
 	}
 
